@@ -67,11 +67,15 @@ g.calibrate = function(datafile, params_rawdata = c(),
                        rmc.headername.recordingid = params_rawdata[["rmc.headername.sn"]],
                        rmc.header.structure = params_rawdata[["rmc.header.structure"]],
                        rmc.check4timegaps = params_rawdata[["rmc.check4timegaps"]])  # Check which file type and monitor brand it is
-  options(warn = 0) #turn off warnings
+  options(warn = 0) #turn on warnings
   mon = INFI$monc
   if (mon == 6) mon = 3
   dformat = INFI$dformc
   sf = INFI$sf
+  # if GENEActiv csv, deprecated function
+  if (mon == 2 & dformat == 2 & length(params_rawdata[["rmc.firstrow.acc"]]) == 0) {
+    stop("The GENEActiv csv reading functionality is deprecated in GGIR from the version 2.6-4 onwards. Please, use either the GENEActiv bin files or try to read the csv files with GGIR::read.myacc.csv")
+  }
   if (length(sf) == 0) { # if sf is not available then try to retrieve sf from rmc.sf
     if (length(params_rawdata[["rmc.sf"]]) == 0) {
       stop("Could not identify sample frequency")
@@ -88,7 +92,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
   suppressWarnings(expr = {decn = g.dotorcomma(datafile, dformat, mon, 
                                                desiredtz = params_general[["desiredtz"]],
                                                rmc.dec = params_rawdata[["rmc.dec"]])}) #detect dot or comma dataformat
-  options(warn = 0) #turn off warnings
+  options(warn = 0) #turn on warnings
   #creating matrixes for storing output
   S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
   NR = ceiling((90*10^6) / (sf*ws4)) + 1000 #NR = number of 'ws4' second rows (this is for 10 days at 80 Hz)
@@ -162,7 +166,11 @@ g.calibrate = function(datafile, params_rawdata = c(),
       if (min(dim(S)) > 1) {
         data = rbind(S,data)
       }
-      
+      # remove 0s if ActiGraph csv (idle sleep mode)
+      if (mon == 3 & dformat == 2) {
+        data = g.imputeTimegaps(x = as.data.frame(data), xyzCol = 1:3, timeCol = c(), sf = sf, impute = FALSE)
+        data = as.matrix(data)
+      }
       LD = nrow(data)
       #store data that could not be used for this block, but will be added to next block
       use = (floor(LD / (ws*sf))) * (ws*sf) #number of datapoint to use
@@ -204,7 +212,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
             use.temp = TRUE
           } else if (mon == 0 & dformat == 5 & length(params_rawdata[["rmc.col.temp"]]) > 0) { # ad-hoc format csv with temperature
             Gx = as.numeric(data[,2]); Gy = as.numeric(data[,3]); Gz = as.numeric(data[,4])
-            temperature = as.numeric(data[,5])
+            temperature = as.numeric(data[, params_rawdata[["rmc.col.temp"]]])
             use.temp = TRUE
           } else if (mon == 0 & dformat == 5 & length(params_rawdata[["rmc.col.temp"]]) == 0) { # ad-hoc format csv without temperature
             Gx = as.numeric(data[,2]); Gy = as.numeric(data[,3]); Gz = as.numeric(data[,4])
@@ -473,7 +481,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
     cat("\n")
     cat(paste0("\nStatus: ",QCmessage))
     cat(paste0("\nCalibration error (g) before: ", cal.error.start))
-    cat(paste0("\nCallibration error (g) after: ", cal.error.end))
+    cat(paste0("\nCalibration error (g) after: ", cal.error.end))
     cat(paste0("\nOffset correction ",c("x","y","z"),": ", offset))
     cat(paste0("\nScale correction ",c("x","y","z"),": ", scale))
     cat(paste0("\nNumber of hours used: ",nhoursused))
