@@ -1,5 +1,5 @@
 g.extractheadervars = function(I) {
-  header= I$header
+  header = I$header
   mon = I$monn
   hnames = rownames(header)
   hvalues = as.character(as.matrix(header))
@@ -11,21 +11,21 @@ g.extractheadervars = function(I) {
     iIDd = hvalues[which(hnames == "Investigator_Id")]			
     iID = as.character(unlist(iIDd))
     HN = "not available" #not stored by genea
-    BodyLocation = hvalues[which(hnames == "Body_Location")]
+    sensor.location = hvalues[which(hnames == "Body_Location")]
     SX = "not available" #not stored by genea
     deviceSerialNumber = hvalues[which(hnames == "Serial_Number")] #serial number
   } else if (mon == "geneactive") {
     ID = hvalues[which(hnames == "Subject_Code")] #; temp2 = unlist(strsplit(as.character(temp)," "))
     iID = hvalues[which(hnames == "Investigator_ID")] #investigator ID
     HN = hvalues[which(hnames == "Handedness_Code")] #handedness
-    BodyLocation = as.character(as.matrix(hvalues[which(hnames == "Device_Location_Code")])) #body location
+    sensor.location = as.character(as.matrix(hvalues[which(hnames == "Device_Location_Code")])) #body location
     SX = hvalues[which(hnames == "Sex")] #gender
     deviceSerialNumber = hvalues[which(hnames == "Device_Unique_Serial_Code")] #serial number
     if (I$dformn == "csv") { #if it was stored in csv-format then underscores were replaced by spaces (by company)
       ID = hvalues[which(hnames == "Subject Code")]# ; temp2 = unlist(strsplit(as.character(temp)," "))
       iID = hvalues[which(hnames == "Investigator ID")] #investigator ID
       HN = hvalues[which(hnames == "Handedness Code")] #handedness
-      BodyLocation = hvalues[which(hnames == "Device Location Code")] #body location
+      sensor.location = hvalues[which(hnames == "Device Location Code")] #body location
       SX = hvalues[which(hnames == "Sex")] #gender
       deviceSerialNumber = hvalues[which(hnames == "Device Unique Serial Code")] #serial number			
     }
@@ -45,7 +45,7 @@ g.extractheadervars = function(I) {
     ID = "not extracted"	# volunteer ID as stored in binary file header
     iID = "not extracted" #investigator ID
     HN = "not extracted" #handedness
-    BodyLocation = "not extracted" #body location
+    sensor.location = "not extracted" #body location
     SX = "not extracted" #gender
   } else if (mon == "axivity" | mon == "movisens") { #todo: create automatic extraction of information from actigraph fileheader
     if (mon  == "actigraph") {
@@ -54,7 +54,7 @@ g.extractheadervars = function(I) {
     ID = "not extracted"	# volunteer ID as stored in binary file header
     iID = "not extracted" #investigator ID
     HN = "not extracted" #handedness
-    BodyLocation = "not extracted" #body location
+    sensor.location = "not extracted" #body location
     SX = "not extracted" #gender
     deviceSerialNumber = "not extracted" #serial number
     if (mon == "axivity") {
@@ -69,7 +69,7 @@ g.extractheadervars = function(I) {
     }
     iID = "not extracted" #investigator ID
     HN = "not extracted" #handedness
-    BodyLocation = "not extracted" #body location
+    sensor.location = "not extracted" #body location
     SX = "not extracted" #gender
     if (length(which(hnames == "device_serial_number")) > 0) {
       deviceSerialNumber = hvalues[which(hnames == "device_serial_number")]			 #serial number
@@ -77,5 +77,6 @@ g.extractheadervars = function(I) {
       deviceSerialNumber = "not extracted" #gender
     }
   }
-  invisible(list(ID=ID,iID=iID,HN=HN,BodyLocation=BodyLocation,SX=SX,deviceSerialNumber=deviceSerialNumber)) #  wdayname=wdayname,wdaycode=wdaycode,wday=wday,ws3=ws3,ws2=ws2
+  invisible(list(ID = ID, iID = iID, HN = HN, sensor.location = sensor.location,
+                 SX = SX, deviceSerialNumber = deviceSerialNumber)) #  wdayname=wdayname,wdaycode=wdaycode,wday=wday,ws3=ws3,ws2=ws2
 }
