@@ -1,7 +1,7 @@
 g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
                    myfun=c(), params_cleaning = c(), params_247 = c(),
                    params_phyact = c(), params_output = c(), params_general = c(), ...) {
-  
+
   #----------------------------------------------------------
   # Extract and check parameters
   input = list(...)
@@ -9,19 +9,21 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
                           params_247 = params_247,
                           params_phyact = params_phyact,
                           params_output = params_output,
-                          params_general = params_general, input = input) # load default parameters
+                          params_general = params_general, input = input,
+                          params2check = c("cleaning", "247", "phyact", "output", "general")) # load default parameters
   params_cleaning = params$params_cleaning
   params_247 = params$params_247
   params_phyact = params$params_phyact
   params_output = params$params_output
   params_general = params$params_general
+
   #-----------------------------
   if (is.numeric(params_247[["qwindow"]])) {
     params_247[["qwindow"]] = params_247[["qwindow"]][order(params_247[["qwindow"]])]
-  } else if (is.character(params_247[["qwindow"]])) { 
-    params_247[["qwindow"]] = g.conv.actlog(params_247[["qwindow"]], params_247[["MX.ig.min.dur"]])
+  } else if (is.character(params_247[["qwindow"]])) {
+    params_247[["qwindow"]] = g.conv.actlog(params_247[["qwindow"]], params_247[["qwindow_dateformat"]])
     # This will be an object with numeric qwindow values for all individuals and days
-  }  
+  }
   #---------------------------------
   # Specifying directories with meta-data and extracting filenames
   path = paste0(metadatadir,"/meta/basic/")  #values stored per long epoch, e.g. 15 minutes
@@ -49,6 +51,7 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
   if (length(f1) ==  0) f1 = length(fnames)
   #--------------------------------
   # get full file path and folder name if requested by end-user and keep this for storage in output
+  foldername = fullfilenames = folderstructure = referencefnames = c()
   if (params_output[["storefolderstructure"]] == TRUE) {
     extractfilenames = function(x) {
       x2 = as.character(unlist(strsplit(x,".RDa"))[1])
@@ -65,16 +68,15 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
   fnames = sort(fnames)
   if (f1 > length(fnames)) f1 = length(fnames)
   if (f0 > f1) f0 = 1
-  
+
   #---------------------------------------
   cnt78 = 1
-  
-  
+
   #=========================================================
   # Declare core functionality, which at the end of this g.part2 is either
   # applied to the file in parallel with foreach or serially with a loop
-  main_part2 = function(i, ffdone, fnames, 
-                        metadatadir = c(), 
+  main_part2 = function(i, ffdone, fnames,
+                        metadatadir = c(),
                         myfun=c(), params_cleaning = c(), params_247 = c(),
                         params_phyact = c(), params_output = c(), params_general = c(),
                         path, ms2.out, foldername, fullfilenames, folderstructure, referencefnames,
@@ -90,7 +92,6 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
     }
     if (params_general[["overwrite"]] == TRUE) skip = 0
     if (skip == 0) {
-      cat(paste0(" ", i))
       M = c()
       filename_dir = c()
       filefoldername = c()
@@ -118,7 +119,7 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
                                  TimeSegments2Zero$windowend < timespan1)
             if (length(validtimes) > 0) {
               TimeSegments2Zero = TimeSegments2Zero[validtimes,c("windowstart","windowend")]
-              
+
             } else {
               TimeSegments2Zero = c()
             }
@@ -133,7 +134,7 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
             M$metashort = M$metashort[,-which(names(M$metashort) %in% myfun$colnames == TRUE)]
           }
         }
-        IMP = g.impute(M, I, 
+        IMP = g.impute(M, I,
                        params_cleaning = params_cleaning,
                        dayborder = params_general[["dayborder"]],
                        desiredtz = params_general[["desiredtz"]],
@@ -150,7 +151,8 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
                         idloc = params_general[["idloc"]],
                         includedaycrit = params_cleaning[["includedaycrit"]],
                         selectdaysfile = params_cleaning[["selectdaysfile"]],
-                        myfun = myfun)
+                        myfun = myfun,
+                        acc.metric = params_general[["acc.metric"]])
         name = as.character(unlist(strsplit(fnames[i], "eta_"))[2])
         if (params_output[["epochvalues2csv"]] == TRUE) {
           if (length(IMP$metashort) > 0) {
@@ -190,13 +192,13 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
           SUM$daysummary$filename_dir = fullfilenames[i] #full filename structure
           SUM$daysummary$foldername = foldername[i] #store the lowest foldername
         }
-        save(SUM,IMP,file = paste0(metadatadir, ms2.out, "/", name)) #IMP is needed for g.plot in g.report.part2
+        save(SUM, IMP, file = paste0(metadatadir, ms2.out, "/", name)) #IMP is needed for g.plot in g.report.part2
       }
       if (M$filecorrupt == FALSE & M$filetooshort == FALSE) rm(IMP)
       rm(M); rm(I)
     }
   } # end of main_part2
-  
+
   #--------------------------------------------------------------------------------
   # Run the code either parallel or in serial (file index starting with f0 and ending with f1)
   if (params_general[["do.parallel"]] == TRUE) {
@@ -204,15 +206,20 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
     Ncores = cores[1]
     if (Ncores > 3) {
       if (length(params_general[["maxNcores"]]) == 0) params_general[["maxNcores"]] = Ncores
-      Ncores2use = min(c(Ncores - 1, params_general[["maxNcores"]]))
-      cl <- parallel::makeCluster(Ncores2use) #not to overload your computer
-      doParallel::registerDoParallel(cl)
+      Ncores2use = min(c(Ncores - 1, params_general[["maxNcores"]], (f1 - f0) + 1))
+      if (Ncores2use > 1) {
+        cl <- parallel::makeCluster(Ncores2use) # not to overload your computer
+        doParallel::registerDoParallel(cl)
+      } else {
+        # Don't process in parallel if only one core
+        params_general[["do.parallel"]] = FALSE
+      }
     } else {
       cat(paste0("\nparallel processing not possible because number of available cores (",Ncores,") < 4"))
       params_general[["do.parallel"]] = FALSE
     }
     cat(paste0('\n Busy processing ... see ', metadatadir, ms2.out, ' for progress\n'))
-    
+
     # check whether we are indevelopment mode:
     GGIRinstalled = is.element('GGIR', installed.packages()[,1])
     packages2passon = functions2passon = NULL
@@ -225,7 +232,7 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
       functions2passon = c("g.analyse", "g.impute", "g.weardec", "g.detecmidnight",
                            "g.extractheadervars", "g.analyse.avday", "g.getM5L5", "g.IVIS",
                            "g.analyse.perday", "g.getbout", "g.analyse.perfile", "g.intensitygradient",
-                           "iso8601chartime2POSIX")
+                           "iso8601chartime2POSIX", "extract_params", "load_params", "check_params")
       errhand = 'stop'
     }
     fe_dopar = foreach::`%dopar%`
@@ -235,13 +242,13 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
     output_list = foreach::foreach(i = f0:f1, .packages = packages2passon,
                                   .export = functions2passon, .errorhandling = errhand, .verbose = F) %myinfix% {
                                     tryCatchResult = tryCatch({
-                                      main_part2(i, ffdone, fnames, metadatadir, 
+                                      main_part2(i, ffdone, fnames, metadatadir,
                                                  myfun, params_cleaning, params_247,
                                                  params_phyact, params_output, params_general,
-                                                 path, ms2.out, foldername, fullfilenames, 
+                                                 path, ms2.out, foldername, fullfilenames,
                                                  folderstructure, referencefnames,
                                                  daySUMMARY, pdffilenumb, pdfpagecount, csvfolder, cnt78)
-                                      
+
                                     })
                                     return(tryCatchResult)
                                   }
@@ -252,12 +259,13 @@ g.part2 = function(datadir = c(), metadatadir = c(), f0 = c(), f1 = c(),
         print(unlist(output_list[oli])) # print any error and warnings observed
       }
     }
-  } else { 
+  } else {
     for (i in f0:f1) {
-      main_part2(i, ffdone, fnames, metadatadir, 
+      cat(paste0(i, " "))
+      main_part2(i, ffdone, fnames, metadatadir,
                  myfun, params_cleaning, params_247,
                  params_phyact, params_output, params_general,
-                 path, ms2.out, foldername, fullfilenames, 
+                 path, ms2.out, foldername, fullfilenames,
                  folderstructure, referencefnames,
                  daySUMMARY, pdffilenumb, pdfpagecount, csvfolder, cnt78)
     }
