@@ -1,12 +1,12 @@
 g.readtemp_movisens = function(datafile, desiredtz = "", from = c(), to = c(), interpolationType=1) {
-    temperature = unisensR::readUnisensSignalEntry(datafile, "temp.bin")
+    temperature = unisensR::readUnisensSignalEntry(dirname(datafile), "temp.bin")
     temperature = as.data.frame(temperature)
-    origin = unisensR::readUnisensStartTime(datafile)
+    origin = unisensR::readUnisensStartTime(dirname(datafile))
     temperature$timestamp = seq(origin, origin + nrow(temperature) - 1, by = 1)
     rawTime = vector(mode = "numeric", nrow(temperature))
     rawTime = as.numeric(as.POSIXlt(temperature$timestamp,tz = desiredtz))
-    rawTemp = as.matrix(temperature[,-c(which(colnames(temperature)=="timestamp"))])
-    acc_length = unisensR::getUnisensSignalSampleCount(datafile, "acc.bin")
+    rawTemp = as.matrix(temperature[,-c(which(colnames(temperature) == "timestamp"))])
+    acc_length = unisensR::getUnisensSignalSampleCount(dirname(datafile), "acc.bin")
     step = (nrow(temperature) - 1) / acc_length   #ratio of temp sf to acc sf in movisens data
     start = rawTime[1]
     end = rawTime[length(rawTime)]
